@@ -1,4 +1,5 @@
-{-# LANGUAGE ScopedTypeVariables
+{-# LANGUAGE CPP
+            ,ScopedTypeVariables
             ,RankNTypes
             ,ExistentialQuantification
             ,MultiParamTypeClasses
@@ -7,6 +8,10 @@
             ,UndecidableInstances
             ,FlexibleContexts #-}
 
+#if __GLASGOW_HASKELL__ >= 708
+{-# LANGUAGE AllowAmbiguousTypes #-}
+#endif
+
 {-
 Copyright (C) 2007 John Goerzen <jgoerzen@complete.org>
 
